#    Jools -- a graphical puzzle game in the Tetris tradition
#    
#    Copyright (C) 2002-2003 Paul Pelzl
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

# initialize.py
#
# Take care of pygame initialization, image and sound loading, etc.
#

import pygame, os
from globals import *
from joolsutils import *
from config import *
import sys


# Initialize pygame
pygame.mixer.pre_init()
pygame.init()
screen = pygame.display.set_mode((SCREENW,SCREENH))
pygame.display.set_caption('Jools')
pygame.mouse.set_visible(1)


if not pygame.mixer.get_init():
   sys.exit("Error: Unable to initialize sound.  Is another program locking the sound card?")
   

# Loading sounds
os.chdir(os.path.join(MEDIAROOT,"sounds"))

point1 = pygame.mixer.Sound("point1.wav")
point2 = pygame.mixer.Sound("point2.wav")
point3 = pygame.mixer.Sound("point3.wav")
point4 = pygame.mixer.Sound("point4.wav")

click  = pygame.mixer.Sound("click.wav")
buzz   = pygame.mixer.Sound("buzz.wav")
click.set_volume(0.02)

try:
   # FIXME: Would be better to allocate more channels,
   # but for some reason it fails on some platforms...
   # pygame.mixer.set_num_channels(30)
   pygame.mixer.set_num_channels(8)
except:
   print "Unable to allocate audio channels."

os.chdir("..")

# Create and draw a simple background
background = pygame.Surface(screen.get_size())
background = background.convert()
#background.fill((250, 250, 250))
background.fill((1, 1, 1))
screen.blit(background, (0, 0))

# Draw the Jools logo
logoImage, logoRect = load_image("images/jools-logo-small.bmp", -1)
screen.blit(logoImage, (0, 0), logoRect)
pygame.display.flip()

# Get a font
joolsFont = pygame.font.Font(None, 25)
highScoreTitleFont = pygame.font.Font(None, 50)
highScoreFont1 = pygame.font.Font(None, 35)
highScoreFont2 = pygame.font.Font(None, 25)

# List of sprites to render at every update
spritesToRender = pygame.sprite.RenderUpdates()

# Load the jool images
imageCache = cacheImages()

# Load the timer image
timerImage, timerRect         = load_image("images/timer-gradient.bmp")
gameOverImage, gameOverRect   = load_image("images/gameover.bmp", -1)
levelUpImage, levelUpRect     = load_image("images/levelup.bmp", -1)
noMovesImage, noMovesRect     = load_image("images/nomoves.bmp", -1)
highScoreImage, highScoreRect = load_image("images/highscore.bmp", -1)
pausedImage, pausedRect       = load_image("images/paused.bmp", -1)



