#    Jools -- a graphical puzzle game in the Tetris tradition
#    
#    Copyright (C) 2002-2003 Paul Pelzl
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

# intro.py
#
# Provide an introductory screen, with options for configuring the
# type of game, starting the game, viewing high scores, etc.
#

import pygame
from initialize import *
from globals import *
import highscore


def displayMenu():
   # Display the main menu.
   # FIXME: Clean this up.  Write some functions to abstract things a bit.
   startTimedButton = pygame.Surface((200, 50))
   startTimedButton.convert()
   startTimedButton.fill((30, 30, 30))
   pygame.draw.polygon(startTimedButton, (0, 61, 216), 
      [(0,0), (198,0), (198,48), (0,48)], 2)

   startUntimedButton = pygame.Surface((200, 50))
   startUntimedButton.convert()
   startUntimedButton.fill((30, 30, 30))
   pygame.draw.polygon(startUntimedButton, (0, 61, 216), 
      [(0,0), (198,0), (198,48), (0,48)], 2)
      
   HSButton = pygame.Surface((200, 50))
   HSButton.convert()
   HSButton.fill((30, 30, 30))
   pygame.draw.polygon(HSButton, (0, 61, 216), 
      [(0,0), (198,0), (198,48), (0,48)], 2)

   quitButton = pygame.Surface((200, 50))
   quitButton.convert()
   quitButton.fill((30, 30, 30))
   pygame.draw.polygon(quitButton, (0, 61, 216), 
      [(0,0), (198,0), (198,48), (0,48)], 2)
   

   startTimedText = joolsFont.render("Start Time Trial Game", 1, (0, 61, 216), (30, 30, 30) )
   STTRect    = startTimedText.get_rect()
   startTimedButton.blit(startTimedText, ((200-STTRect.width)/2, (50-STTRect.height)/2))

   startUntimedText = joolsFont.render("Start Untimed Game", 1, (0, 61, 216), (30, 30, 30) )
   SUTRect    = startUntimedText.get_rect()
   startUntimedButton.blit(startUntimedText, ((200-SUTRect.width)/2, (50-SUTRect.height)/2))

   HSText  = joolsFont.render("High Scores", 1, (0, 61, 216), (30, 30, 30) )
   HSTRect     = HSText.get_rect()
   HSButton.blit(HSText, ((200-HSTRect.width)/2, (50-HSTRect.height)/2))

   quitText = joolsFont.render("Quit", 1, (0, 61, 216), (30, 30, 30) )
   QTRect   = quitText.get_rect()
   quitButton.blit(quitText, ((200-QTRect.width)/2, (50-QTRect.height)/2))
   
   screen.blit(background, (0,100), (0,100,640,380))
   screen.blit(startTimedButton, (220, 100))
   screen.blit(startUntimedButton, (220, 175))
   screen.blit(HSButton,  (220, 250))
   screen.blit(quitButton, (220, 325))


   joolsFont.set_italic(1)
   versionText = joolsFont.render("Jools v"+VERSION, 1, (0,232,3), (1,1,1) )
   authorText  = joolsFont.render("written by Paul Pelzl", 1, (0,232,3), (1,1,1) )
   joolsFont.set_italic(0)
   vRect = versionText.get_rect()
   aRect = authorText.get_rect()

   screen.blit(versionText, (630-aRect.width, 480-aRect.height-vRect.height) )
   screen.blit(authorText, (630-aRect.width, 480-aRect.height) )


   pygame.display.update()
   pygame.display.flip()




def showIntro():

   displayMenu()

   # Process clicks
   # Mouse button must be read as released at least once before
   # a click will be recognized.
   clickable = 0
   while 1:
      if pygame.mouse.get_pressed()[0]:
         if clickable:
            mousePos = pygame.mouse.get_pos()
            if (mousePos[0] >= 220 and mousePos[0] < 420 and
               mousePos[1] >= 100 and mousePos[1] < 150):
               screen.blit(background, (0,100), (0,100,640,380))
               pygame.display.update()
               pygame.display.flip()
               return 1
            if (mousePos[0] >= 220 and mousePos[0] < 420 and
               mousePos[1] >= 175 and mousePos[1] < 225):
               screen.blit(background, (0,100), (0,100,640,380))
               pygame.display.update()
               pygame.display.flip()
               return 0
            elif (mousePos[0] >= 220 and mousePos[0] < 420 and
               mousePos[1] >= 250 and mousePos[1] < 300):
               highscore.showScores()
               clickable = 0
               displayMenu()
            elif (mousePos[0] >= 220 and mousePos[0] < 420 and
               mousePos[1] >= 325 and mousePos[1] < 375):
               pygame.quit()
               sys.exit("Exiting Jools...")
      else:
         clickable = 1
      pygame.event.pump()
      if pygame.event.peek(QUIT):
         pygame.quit()
         sys.exit("Exiting Jools...")
      pygame.time.wait(READ_INPUT_DELAY)



